@@ -673,140 +673,9 @@ gguse_linear_coord <- function(plot, layout_name) {
     plot
 }
 
-view_scales_polar <- function(scale, theta, coord_limits, expand = TRUE) {
-    aesthetic <- scale$aesthetics[1]
-    is_theta <- theta == aesthetic
-    name <- if (is_theta) "theta" else "r"
-    ggdefault_expansion <- function(scale, discrete = expansion(add = 0.6),
-                                    continuous = expansion(mult = 0.05),
-                                    expand = TRUE) {
-        out <- expansion()
-        if (!any(expand)) {
-            return(out)
-        }
-        scale_expand <- scale$expand %|w|%
-            if (scale$is_discrete()) discrete else continuous
-
-        # for backward compatibility, we ensure expansions have expected length
-        expand <- rep_len(expand, 2L)
-        scale_expand <- rep_len(scale_expand, 4)
-
-        if (expand[1]) {
-            out[1:2] <- scale_expand[1:2]
-        }
-        if (expand[2]) {
-            out[3:4] <- scale_expand[3:4]
-        }
-        out
-    }
-    expansion <- ggdefault_expansion(scale, expand = expand)
-    limits <- scale$get_limits()
-    continuous_range <- ggfun("expand_limits_scale")(
-        scale, expansion, limits, coord_limits = coord_limits
-    )
-    primary <- ggfun("view_scale_primary")(scale, limits, continuous_range)
-    view_scales <- list(
-        primary,
-        sec = ggfun("view_scale_secondary")(scale, limits, continuous_range),
-        major = primary$map(primary$get_breaks()),
-        minor = primary$map(primary$get_breaks_minor()),
-        range = continuous_range
-    )
-    names(view_scales) <- c(name, paste0(name, ".", names(view_scales)[-1]))
-    view_scales
-}
-
-gguse_radial_coord <- function(plot, coord, ..., layout_name) {
-    setup_panel_params <- function(self, scale_x, scale_y, params = list()) {
-        params <- c(
-            view_scales_polar(
-                scale_x, self$theta,
-                self$limits$x,
-                expand = params$expand[c(4, 2)]
-            ),
-            view_scales_polar(
-                scale_y, self$theta,
-                self$limits$y,
-                expand = params$expand[c(3, 1)]
-            ),
-            list(
-                bbox = ggfun("polar_bbox")(
-                    self$arc, inner_radius = self$inner_radius
-                ),
-                arc = self$arc, inner_radius = self$inner_radius
-            )
-        )
-        axis_rotation <- self$r_axis_inside
-        if (is.numeric(axis_rotation)) {
-            theta_scale <- switch(self$theta,
-                x = scale_x,
-                y = scale_y
-            )
-            axis_rotation <- theta_scale$transform(axis_rotation)
-            axis_rotation <- scales::oob_squish(
-                axis_rotation, params$theta.range
-            )
-            axis_rotation <- ggfun("theta_rescale")(
-                axis_rotation, params$theta.range,
-                params$arc, 1
-            )
-            params$axis_rotation <- rep_len(axis_rotation, length.out = 2)
-        } else {
-            params$axis_rotation <- params$arc
-        }
-        params
-    }
-    parse_coord_expand <- function(expand) {
-        if (is.numeric(expand) && all(expand %in% c(0, 1))) {
-            expand <- as.logical(expand)
-        }
-        ggfun("check_logical")(expand)
-        if (anyNA(expand)) {
-            cli::cli_abort("{.arg expand} cannot contain missing values.")
-        }
-
-        if (!rlang::is_named(expand)) {
-            return(rep_len(expand, 4))
-        }
-
-        # Match by top/right/bottom/left
-        out <- rep(TRUE, 4)
-        i <- match(names(expand), ggfun(".trbl"))
-        if (sum(!is.na(i)) > 0) {
-            out[i] <- unname(expand)[!is.na(i)]
-        }
-        out
-    }
-    setup_params <- function(self, data) {
-        params <- list(
-            guide_default = ggfun("guide_axis")(),
-            guide_missing = ggfun("guide_none")(),
-            expand = parse_coord_expand(self$expand %||% TRUE)
-        )
-        if (!isFALSE(self$r_axis_inside)) {
-            return(params)
-        }
-        place <- ggfun("in_arc")(c(0, 0.5, 1, 1.5) * pi, self$arc)
-        if (!any(place)) {
-            cli::cli_warn(c(
-                "No appropriate placement found for {.arg r_axis_inside}.",
-                i = "Axis will be placed at panel edge."
-            ))
-            params$r_axis_inside <- TRUE
-            return(params)
-        }
-
-        params$r_axis <- if (any(place[c(1, 3)])) "left" else "bottom"
-        params$fake_arc <- switch(which(place[c(1, 3, 2, 4)])[1],
-            c(0, 2),
-            c(1, 3),
-            c(0.5, 2.5),
-            c(1.5, 3.5)
-        ) * pi
-        params
-    }
+gguse_circle_coord <- function(plot, coord, ..., layout_name) {
     if (inherits(plot_coord <- plot$coordinates, "CoordRadial")) {
-        plot$coordinates <- ggproto(
+        out <- ggproto(
             NULL, plot_coord,
             theta = coord$theta,
             r = coord$r,
@@ -815,8 +684,7 @@ gguse_radial_coord <- function(plot, coord, ..., layout_name) {
             r_axis_inside = coord$r_axis_inside,
             expand = coord$expand,
             ...,
-            setup_params = setup_params,
-            setup_panel_params = setup_panel_params
+            setup_panel_params = circle_panel_params
         )
     } else {
         if (!isTRUE(plot$coordinates$default)) {
@@ -828,12 +696,15 @@ gguse_radial_coord <- function(plot, coord, ..., layout_name) {
                 i = sprintf("Will use {.fn %s} instead", snake_class(coord))
             ))
         }
-        plot$coordinates <- ggproto(NULL, coord, ...,
-            setup_params = setup_params,
-            setup_panel_params = setup_panel_params
-        )
+        if (!inherits(coord, "CoordCircle")) {
+            out <- ggproto(NULL, coord, ...,
+                setup_panel_params = circle_panel_params
+            )
+        } else {
+            out <- ggproto(NULL, coord, ...)
+        }
     }
-    plot
+    out
 }
 
 ######################################################
