@@ -1,5 +1,3 @@
-`%||%` <- function(x, y) if (is.null(x)) y else x
-
 # `vec_rep`
 recycle_whole <- function(x, len) {
     out <- x %% len
@@ -45,16 +43,12 @@ names_or_index <- function(x) {
 #' @export
 read_example <- function(file = NULL) {
     if (is.null(file)) {
-        dir(example_file())
+        dir(pkg_extdata())
     } else {
-        readRDS(example_file(file, mustWork = TRUE))
+        readRDS(pkg_extdata(file, mustWork = TRUE))
     }
 }
 
-example_file <- function(..., base = "extdata") {
-    system.file(base, ..., package = pkg_nm())
-}
-
 with_options <- function(code, ...) {
     opts <- options(...)
     on.exit(options(opts))
@@ -112,9 +106,6 @@ override_call <- function(call = NULL) {
     )
 }
 
-#' @importFrom utils packageName
-pkg_nm <- function() packageName(topenv(environment()))
-
 # library(data.table)
 # library(vctrs)
 # `%nest_unique%` <- function(x, y) {
@@ -253,38 +244,3 @@ fclass <- function(x) .subset(class(x), 1L)
 is_scalar <- function(x) length(x) == 1L
 
 is_scalar_numeric <- function(x) length(x) == 1L && is.numeric(x)
-
-# utils function to collapse characters ---------------------------
-oxford_and <- function(chr, code = TRUE, quote = TRUE, sep = ", ") {
-    oxford_comma(code_quote(chr, code, quote), sep = sep, final = "and")
-}
-
-oxford_or <- function(chr, code = TRUE, quote = TRUE, sep = ", ") {
-    oxford_comma(code_quote(chr, code, quote), sep = sep, final = "or")
-}
-
-code_quote <- function(x, code = TRUE, quote = TRUE) {
-    if (quote) x <- paste0("\"", x, "\"")
-    if (code) x <- paste0("`", x, "`")
-    x
-}
-
-oxford_comma <- function(chr, sep = ", ", final = "and") {
-    n <- length(chr)
-
-    if (n < 2L) {
-        return(chr)
-    }
-
-    head <- chr[seq_len(n - 1L)]
-    last <- chr[n]
-
-    head <- paste(head, collapse = sep)
-
-    # Write a or b. But a, b, or c.
-    if (n > 2L) {
-        paste0(head, sep, final, " ", last)
-    } else {
-        paste0(head, " ", final, " ", last)
-    }
-}
